==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/tour/messages/pt-BR/base.php <==
<?php
return array (
  ' Remove panel' => 'Remover o painel',
  '<strong>Account</strong> Menu' => 'Menu da <strong>Conta</strong>',
  '<strong>Getting</strong> Started' => '<strong>Primeiros Passos</strong>',
  '<strong>Guide:</strong> Administration (Modules)' => '<strong>Guia:</strong> Administração (Módulos)',
  '<strong>Guide:</strong> Overview' => '<strong>Guia:</strong> Visão geral',
  '<strong>Guide:</strong> Spaces' => '<strong>Guia:</strong> Espaços',
  '<strong>Guide:</strong> User profile' => '<strong>Guia:</strong> Perfil do usuário',
  '<strong>Notifications</strong>' => '<strong>Notificações</strong>',
  '<strong>Remove</strong> tour panel' => '<strong>Remover</strong> painel de guia',
  '<strong>Space</strong> Menu' => 'Menu do <strong>Espaço</strong>',
  '<strong>Start</strong> space guide' => '<strong>Iniciar</strong> guia do espaço',
  'Cancel' => 'Cancelar',
  'Don\'t lose track of things!<br /><br />This icon will keep you informed of activities and posts that concern you directly.' => 'Não perder a noção das coisas! <br /><br />Este ícone irá mantê-lo informado sobre as atividades e os posts que dizem respeito diretamente a você.',
  'Drag a photo here or click to browse your files' => 'Arraste uma foto aqui ou clique para procurar seus arquivos',
  'End guide' => 'Fim do guia',
  'Get to know your way around the site\'s most important features with the following guides:' => 'Conheça as características mais importantes do site com os seguintes guias:',
  'Hide my year of birth' => 'Esconder meu ano de nascimento',
  'Howdy <strong>%firstname%</strong>, thank you for using %community%.' => '',
  'Next »' => 'Próximo »',
  'Ok' => 'Ok',
  'Save and close' => 'Salvar e fechar',
  'The account menu gives you access to your private settings and allows you to manage your public profile.' => 'O menu conta dá acesso às suas configurações privadas e permite-lhe gerenciar o seu perfil público.',
  'This action will remove the tour panel from your dashboard. You can reactivate it at<br>Account settings <i class="fa fa-caret-right"></i> Settings.' => 'Essa ação irá remover o painel de guia do seu painel. Você pode reativa-lo nas<br><i class="fa fa-caret-right"></i> Configurações de Conta.',
  'This is the most important menu and will probably be the one you use most often!<br><br>Access all the spaces you have joined and create new spaces here.<br><br>The next guide will show you how:' => 'Este é o menu mais importante e, provavelmente, vai ser o que você usará com mais frequência.<br><br>Permite acessar todos os espaços que você faz parte e criar novos espaços.<br><br>O próximo guia vai te mostrar como fazer:',
  'You are the first user here... Yehaaa! Be a shining example and complete your profile,<br>so that future users know who is the top dog here and to whom they can turn to if they have questions.' => 'Você é o primeiro usuário aqui ... Yehaaa! Seja um exemplo brilhante e complete o seu perfil, <br> para que os futuros usuários saibam quem é o superior aqui e para quem eles possam recorrer se tiverem dúvidas.',
  'Your firstname' => 'Seu primeiro nome',
  'Your lastname' => 'Your lastname',
  'Your mobile phone number' => 'Seu telefone móvel',
  'Your phone number at work' => 'Seu número de telefone no trabalho',
  'Your skills, knowledge and experience (comma seperated)' => 'Suas habilidades, conhecimentos e experiência (separados por vírgula)',
  'Your title or position' => 'Seu título ou posição',
  '« Prev' => '« Anterior',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/tour/messages/pt-BR/base.php <==
<?php
return array (
  ' Remove panel' => 'Remover o painel',
  '<strong>Account</strong> Menu' => 'Menu da <strong>Conta</strong>',
  '<strong>Getting</strong> Started' => '<strong>Primeiros Passos</strong>',
  '<strong>Guide:</strong> Administration (Modules)' => '<strong>Guia:</strong> Administração (Módulos)',
  '<strong>Guide:</strong> Overview' => '<strong>Guia:</strong> Visão geral',
  '<strong>Guide:</strong> Spaces' => '<strong>Guia:</strong> Espaços',
  '<strong>Guide:</strong> User profile' => '<strong>Guia:</strong> Perfil do usuário',
  '<strong>Notifications</strong>' => '<strong>Notificações</strong>',
  '<strong>Remove</strong> tour panel' => '<strong>Remover</strong> painel de guia',
  '<strong>Space</strong> Menu' => 'Menu do <strong>Espaço</strong>',
  '<strong>Start</strong> space guide' => '<strong>Iniciar</strong> guia do espaço',
  'Cancel' => 'Cancelar',
  'Don\'t lose track of things!<br /><br />This icon will keep you informed of activities and posts that concern you directly.' => 'Não perder a noção das coisas! <br /><br />Este ícone irá mantê-lo informado sobre as atividades e os posts que dizem respeito diretamente a você.',
  'Drag a photo here or click to browse your files' => 'Arraste uma foto aqui ou clique para procurar seus arquivos',
  'End guide' => 'Fim do guia',
  'Get to know your way around the site\'s most important features with the following guides:' => 'Conheça as características mais importantes do site com os seguintes guias:',
  'Hide my year of birth' => 'Esconder meu ano de nascimento',
  'Howdy <strong>%firstname%</strong>, thank you for using %community%.' => 'Olá <strong>% firstname% </strong>, obrigado por usar o% community%.',
  'Next »' => 'Próximo »',
  'Ok' => 'Ok',
  'Save and close' => 'Salvar e fechar',
  'The account menu gives you access to your private settings and allows you to manage your public profile.' => 'O menu conta dá acesso às suas configurações privadas e permite-lhe gerenciar o seu perfil público.',
  'This action will remove the tour panel from your dashboard. You can reactivate it at<br>Account settings <i class="fa fa-caret-right"></i> Settings.' => 'Essa ação irá remover o painel de guia do seu painel. Você pode reativa-lo nas<br /><i class="fa fa-caret-right"></i> Configurações de Conta.',
  'This is the most important menu and will probably be the one you use most often!<br><br>Access all the spaces you have joined and create new spaces here.<br><br>The next guide will show you how:' => 'Este é o menu mais importante e, provavelmente, vai ser o que você usará com mais frequência.<br /><br />Permite acessar todos os espaços que você faz parte e criar novos espaços.<br /><br />O próximo guia vai te mostrar como fazer:',
  'You are the first user here... Yehaaa! Be a shining example and complete your profile,<br>so that future users know who is the top dog here and to whom they can turn to if they have questions.' => 'Você é o primeiro usuário aqui ... Yehaaa! Seja um exemplo brilhante e complete o seu perfil, <br /> para que os futuros usuários saibam quem é o superior aqui e para quem eles possam recorrer se tiverem dúvidas.',
  'Your firstname' => 'Seu primeiro nome',
  'Your lastname' => 'Your lastname',
  'Your mobile phone number' => 'Seu telefone móvel',
  'Your phone number at work' => 'Seu número de telefone no trabalho',
  'Your skills, knowledge and experience (comma seperated)' => 'Suas habilidades, conhecimentos e experiência (separados por vírgula)',
  'Your title or position' => 'Seu título ou posição',
  '« Prev' => '« Anterior',
);
